@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 2006-2010 by Peter Penz <peter.penz19@gmail.com>        *
- *   Copyright (C) 2006 by Aaron J. Seigo <aseigo@kde.org>                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2006-2010 Peter Penz <peter.penz19@gmail.com>
+ * SPDX-FileCopyrightText: 2006 Aaron J. Seigo <aseigo@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "viewproperties.h"
 
@@ -279,7 +266,7 @@ void ViewProperties::setVisibleRoles(const QList<QByteArray>& roles)
 
     // Add the updated values for the current view-mode
     newVisibleRoles.reserve(roles.count());
-    foreach (const QByteArray& role, roles) {
+    for (const QByteArray& role : roles) {
         newVisibleRoles.append(prefix + role);
     }
 
@@ -322,7 +309,7 @@ QList<QByteArray> ViewProperties::visibleRoles() const
     const int prefixLength = prefix.length();
 
     const QStringList visibleRoles = m_node->visibleRoles();
-    foreach (const QString& visibleRole, visibleRoles) {
+    for (const QString& visibleRole : visibleRoles) {
         if (visibleRole.startsWith(prefix)) {
             const QByteArray role = visibleRole.right(visibleRole.length() - prefixLength).toLatin1();
             if (role != "text") {
@@ -405,7 +392,7 @@ bool ViewProperties::exist() const
 
 QString ViewProperties::destinationDir(const QString& subDir) const
 {
-    QString path = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+    QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
     path.append("/view_properties/").append(subDir);
     return path;
 }
@@ -435,7 +422,7 @@ void ViewProperties::convertAdditionalInfo()
         // the internal role. One special-case must be handled: "LinkDestination"
         // has been used for "destination".
         visibleRoles.reserve(additionalInfo.count());
-        foreach (const QString& info, additionalInfo) {
+        for (const QString& info : additionalInfo) {
             QString visibleRole = info;
             int index = visibleRole.indexOf('_');
             if (index >= 0 && index + 1 < visibleRole.length()) {
